/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none

Files needed: 

cpiai.txt - from BLS - ftp://ftp.bls.gov/pub/special.requests/cpi/cpiai.txt 

*/

*-----------------------------------*
*    PREPARE CPI DEFLATOR HISTORY   *
*-----------------------------------*

* 1. Annual conversions to dollars 2011 (from the BLS's annual CPI values)

clear
set more off

infix str temp 1-1000 using "cpiai.txt" , clear

local maxobs = _N
drop in 139/`maxobs'
drop in 1/19 // Removes header rows

gen year = substr(temp , -134, 4)

gen cpiu1 = substr(temp, -130, 9)
gen cpiu2 = substr(temp, -121, 9)
gen cpiu3 = substr(temp, -112, 9)
gen cpiu4 = substr(temp, -103, 9)
gen cpiu5 = substr(temp, -94, 9)
gen cpiu6 = substr(temp, -85, 9)
gen cpiu7 = substr(temp, -85, 9)
gen cpiu8 = substr(temp, -76, 9)
gen cpiu9 = substr(temp, -67, 9)
gen cpiu10 = substr(temp, -58, 9)
gen cpiu11 = substr(temp, -49, 9)
gen cpiu12 = substr(temp, -40, 9)

gen annual = substr(temp, -31, 9)

order year cpiu1-cpiu12 annual
drop temp

drop if year == ""

destring year annual cpiu* , force replace

reshape long cpiu , i(year) j(month)

keep year annual
duplicates drop

gen dol2011 = 225.672 / annual

drop annual

label variable year "Year"
label variable dol2011 "CPI-Urban adjustment factor to dollars 2011"

compress
save dollars2011_cpiu_annual , replace

******

* 2. Monthly conversions to dollars 2011 (from the BLS's monthly CPI values)

clear
set more off

infix str temp 1-1000 using "cpiai.txt" , clear

local maxobs = _N
drop in 139/`maxobs'
drop in 1/19 // Removes header rows

gen year = substr(temp , -134, 4)

gen cpiu1 = substr(temp, -130, 9)
gen cpiu2 = substr(temp, -121, 9)
gen cpiu3 = substr(temp, -112, 9)
gen cpiu4 = substr(temp, -103, 9)
gen cpiu5 = substr(temp, -94, 9)
gen cpiu6 = substr(temp, -85, 9)
gen cpiu7 = substr(temp, -85, 9)
gen cpiu8 = substr(temp, -76, 9)
gen cpiu9 = substr(temp, -67, 9)
gen cpiu10 = substr(temp, -58, 9)
gen cpiu11 = substr(temp, -49, 9)
gen cpiu12 = substr(temp, -40, 9)

gen annual = substr(temp, -31, 9)

order year cpiu1-cpiu12 annual
drop temp annual

drop if year == ""

destring year cpiu* , force replace

reshape long cpiu , i(year) j(month)

gen dol2011 = 1 if year == 2011

quietly forv m = 1/12 {
gen temp = cpiu if month == `m' & year == 2011
egen mtemp = max(temp)
replace dol2011 = mtemp/cpiu if year != 2011 & month == `m'
drop temp mtemp
}

drop cpiu

label variable year "Year"
label variable month "Month"
label variable dol2011 "CPI-Urban adjustment factor to dollars 2011"

compress
save dollars2011_cpiu_monthly , replace

******

* 3. Quarterly conversions to dollars 2011 (from averaging the monthly CPI values within each quarter)

use dollars2011_cpiu_monthly , clear

gen quarter = quarter(mdy(month, 1, year))
order quarter , after(year)

drop month

collapse (mean) dol2011 , by(year quarter)

label variable year "Year"
label variable quarter "Quarter"
label variable dol2011 "CPI-Urban adjustment factor to dollars 2011"

compress
save dollars2011_cpiu_quarterly , replace
