/* Last modified: August 19, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none
Do-files called: none
Files needed: none

*/

*--------------------*
* Set these:

global datadir "/home/jeremy/data/jhr/data_code" // Location of data and code
global savedir "/home/jeremy/data/jhr/tex" // Location of figures and tables folders

*--------------------*

clear all
set more off
cd "$datadir"

* These are all fake data in fictional examples used as illustration.

set obs 3
gen id = _n
expand = 8
sort id
gen time = 1 if id != id[_n-1]
replace time = time[_n-1] + 1 if time == .
xtset id time
sort id time
gen x = 0
replace x = 1 if id == 2 & time >= 3
replace x = 1 if id == 3 & time >= 5
bysort id: gen cumx = sum(x)
gen y = 3 - cumx
replace y = 1 if cumx > 2

line y time if id == 1 , lcolor(gs13) lpattern(solid) lwidth(1.5) || ///
line y time if id == 2 , lcolor(gs4) lpattern(dash) || ///
line y time if id == 3 , lcolor(black) lpattern(dot) ///
legend(rows(1) order(1 "[1] Control" 2 "[2] Treated (>t2)" 3 "[3] Treated (>t4)")) ///
ytitle("Employment level") xtitle("Time period") xlab(1 2 3 4 5 6 7 8) ylab(0 1 2 3) ///
graphregion(color(white)) 

graph export "$savedir/figures/FigA1-1-toy_example_methods.png" , replace width(2000)

*** Fixed effects

qui eststo fe0: reg y x i.id i.time
qui eststo fe1: reg y x i.id i.time if id != 3
qui eststo fe2: reg y x i.id i.time if id != 2
qui eststo fe3: reg y x i.id i.time if id != 1

*** First difference

qui eststo fd0: reg D.y D.x i.time
qui eststo fd1: reg D.y D.x i.time if id != 3
qui eststo fd2: reg D.y D.x i.time if id != 2
qui eststo fd3: reg D.y D.x i.time if id != 1

*** Long difference (2 period)

qui eststo ld2_0: reg S2.y S2.x i.time
qui eststo ld2_1: reg S2.y S2.x i.time if id != 3
qui eststo ld2_2: reg S2.y S2.x i.time if id != 2
qui eststo ld2_3: reg S2.y S2.x i.time if id != 1

*** Long difference (3 period)

qui eststo ld3_0: reg S3.y S3.x i.time
qui eststo ld3_1: reg S3.y S3.x i.time if id != 3
qui eststo ld3_2: reg S3.y S3.x i.time if id != 2
qui eststo ld3_3: reg S3.y S3.x i.time if id != 1

*** Long difference (4 period)

qui eststo ld4_0: reg S4.y S4.x i.time
qui eststo ld4_1: reg S4.y S4.x i.time if id != 3
qui eststo ld4_2: reg S4.y S4.x i.time if id != 2
qui eststo ld4_3: reg S4.y S4.x i.time if id != 1

/*
*** Distributed lag in levels (contemporaneous + 1 lag term)

qui reg y L(0/1).x i.id i.time
qui lincomest x + L1.x
qui estimates store dlfe0

qui reg y L(0/1).x i.id i.time if id != 3
qui lincomest x + L1.x
qui estimates store dlfe1

qui reg y L(0/1).x i.id i.time if id != 2
qui lincomest x + L1.x
qui estimates store dlfe2

qui reg y L(0/1).x i.id i.time if id != 1
qui lincomest x + L1.x
qui estimates store dlfe3
*/

*** Distributed lag in first-differences (contemporaneous + 1 lag term)

qui reg D.y DL(0/1).x i.id i.time
qui lincomest D.x + DL1.x
qui estimates store dlfd0

qui reg D.y DL(0/1).x i.id i.time if id != 3
qui lincomest D.x + DL1.x
qui estimates store dlfd1

qui reg D.y DL(0/1).x i.id i.time if id != 2
qui lincomest D.x + DL1.x
qui estimates store dlfd2

qui reg D.y DL(0/1).x i.id i.time if id != 1
qui lincomest D.x + DL1.x
qui estimates store dlfd3


*** RESULTS

* Fixed effect:
esttab fe1 fe2 fe3 fe0 using "$savedir/tables/table_toy_example_methods.tex", replace fragment ///
keep(*x*) noobs nonum nostar not nogap b(2) ///
coeflabels(x "Fixed effects (classic)") ///
mtitles("1,2" "1,3" "2,3" "1,2,3")

* First difference:
esttab fd1 fd2 fd3 fd0 using "$savedir/tables/table_toy_example_methods.tex", append fragment ///
keep(*x*) nomtitles noobs nonum nostar not nogap b(2) ///
coeflabels(D.x "First difference (FD)")

* Long difference (2 period):
esttab ld2_1 ld2_2 ld2_3 ld2_0 using "$savedir/tables/table_toy_example_methods.tex", append fragment ///
keep(*x*) nomtitles noobs nonum nostar not nogap b(2) ///
coeflabels(S2.x "Long difference (2 period)")

* Long difference (3 period):
esttab ld3_1 ld3_2 ld3_3 ld3_0 using "$savedir/tables/table_toy_example_methods.tex", append fragment ///
keep(*x*) nomtitles noobs nonum nostar not nogap b(2) ///
coeflabels(S3.x "Long difference (3 period)")

* Long difference (4 period):
esttab ld4_1 ld4_2 ld4_3 ld4_0 using "$savedir/tables/table_toy_example_methods.tex", append fragment ///
keep(*x*) nomtitles noobs nonum nostar not nogap b(2) ///
coeflabels(S4.x "Long difference (4 period)")

/*
* Distributed lag in levels (current + 1 lag):
esttab dlfe1 dlfe2 dlfe3 dlfe0 using "$savedir/tables/table_toy_example_methods.tex", append fragment ///
nomtitles noobs nonum nostar not nogap b(2) ///
coeflabels((1) "Distributed lag levels (2 period)")
*/

* Distributed lag in first-differences (current + 1 lag):
esttab dlfd1 dlfd2 dlfd3 dlfd0 using "$savedir/tables/table_toy_example_methods.tex", append fragment ///
nomtitles noobs nonum nostar not nogap b(2) ///
coeflabels((1) "Distributed lag FD (2 period)")
