/* Last modified: August 19, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html

Files needed: 

qcew.dta - a cleaned version of the Quarterly Census of Employment and Wages, linked to State minimum wage data and other covariates

qwi.dta - a cleaned version of the Quarterly Worforce Indicators, linked to State minimum wage data and other covariates

*/

*--------------------*
* Set these:

global datadir "/home/jeremy/data/jhr/data_code" // Location of data and code
global savedir "/home/jeremy/data/jhr/tex" // Location of figures and tables folders

*--------------------*

clear all
set more off
set matsize 4000
cd "$datadir"

*--------------------*
*    BY INDUSTRY     *
*--------------------*

clear all
set more off
set matsize 2000

* Define some shorter value labels for purposes of the Table
program newindlab
label define newindlab 10 "All: NAICS available (1990-)"
label define newindlab 11 "11: Agriculture and wildlife" , add
label define newindlab 21 "21: Mining" , add
label define newindlab 22 "22: Utilities" , add
label define newindlab 23 "23: Construction" , add
label define newindlab 31 "31-33: Manufacturing" , add
label define newindlab 42 "42: Wholesale trade" , add
label define newindlab 44 "44-45: Retail trade" , add
label define newindlab 48 "48-49: Transportation and warehouse" , add
label define newindlab 51 "51: Information service" , add
label define newindlab 52 "52: Finance and insurance" , add
label define newindlab 53 "53: Real estate" , add
label define newindlab 54 "54: Professional service" , add
label define newindlab 55 "55: Management" , add
label define newindlab 56 "56: Administrative support" , add
label define newindlab 61 "61: Education related" , add
label define newindlab 62 "62: Health care" , add
label define newindlab 71 "71: Arts and entertainment" , add
label define newindlab 72 "72: Accommodation and food" , add
label define newindlab 81 "81: Other service" , add
label define newindlab 92 "92: Public administration" , add
label values industry newindlab
end

* QCEW

use qcew , clear
newindlab
keep if industry == 10 & quarterly >= 121 // Drops pre-1990 (pre-NAICS) data
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

local j = 12
local industry = 10

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin

estimates store qcew`industry'

foreach industry in 11 21 22 23 31 42 44 48 51 52 53 54 55 56 61 62 71 72 81 92 {

use qcew , clear
newindlab
keep if industry == `industry' & quarterly >= 121 // Drops pre-1990 (pre-NAICS) data
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

local j = 12

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin

estimates store qcew`industry'
}

* QWI

use qwi , clear
newindlab
keep if industry == 10 & agegrp == 0
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

local j = 12
local industry = 10

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin

estimates store qwi`industry'

foreach industry in 11 21 22 23 31 42 44 48 51 52 53 54 55 56 61 62 71 72 81 92 {

use qwi , clear
newindlab
keep if industry == `industry' & agegrp == 0
sort state quarterly
xtset state quarterly
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 quarterly // Setting some technical factor-variable settings

local j = 12

qui reg D.lemp DL(0/15).lnmin i.quarterly#i.censusreg S4.lpopall S4.share1559 S4.lrgspcap , robust cluster(state)

qui lincomest D.lnmin + DL.lnmin + DL2.lnmin + DL3.lnmin + DL4.lnmin + DL5.lnmin + DL6.lnmin + DL7.lnmin + DL8.lnmin + ///
DL9.lnmin + DL10.lnmin + DL11.lnmin + DL12.lnmin + DL13.lnmin + DL14.lnmin + DL15.lnmin

estimates store qwi`industry'
}

#delimit ;
esttab qcew10 qwi10 using "$savedir/tables/table_industry.tex", replace fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) nonotes nogaps wide nonum nomtitles
coeflabels((1) "`:label newindlab 10'")
;
#delimit cr

foreach industry in 11 21 22 23 31 42 44 48 51 52 53 54 55 56 61 62 71 72 81 92 {

#delimit ;
esttab qcew`industry' qwi`industry' using "$savedir/tables/table_industry.tex", append fragment
b(4) se(4) label star(* 0.1 ** 0.05 *** 0.01) nonotes nogaps noobs nomtitles wide nonum
coeflabels((1) "`:label newindlab `industry''") 
;
#delimit cr

}
